@@ -7,12 +7,13 @@ movies = [
 ]
 
 
-def print_lol(the_list, level):
+def print_lol(the_list, indent=False, level=0):
     """This function takes a list argument and each item of the list is printed on the screen in its own line """
     for each_item in the_list:
         if isinstance(each_item, list):
-            print_lol(each_item, level + 1)
+            print_lol(each_item, indent, level + 1)
         else:
-            for num in range(level):
-                print('\t', end='')
-            print(each_item)
\ No newline at end of file
+            if indent:
+                for num in range(level):
+                    print('\t', end='')
+            print(each_item)
